Staging area view โ shows unstaged changes, staged changes, and commit message input side-by-side as three columns at the bottom of the main layout.
Functions
- view
- Render the full staging area panel (unstaged | staged | commit input).