Named constants for Bootstrap icon codepoints used throughout the GUI.
Using named constants instead of raw unicode literals makes the code self-documenting and prevents codepoint typos.
Named constants for Bootstrap icon codepoints used throughout the GUI.
Using named constants instead of raw unicode literals makes the code self-documenting and prevents codepoint typos.