Structs
- GitKraft
- Top-level application state for the GitKraft GUI.
- RepoTab
- Per-repository state — one instance per open tab.
Enums
- Context
Menu - What item was right-clicked to open the context menu.
- Drag
Target - Which vertical divider the user is currently dragging (if any).
- Drag
TargetH - Which horizontal divider the user is currently dragging (if any).