toolbar_btn

Function toolbar_btn 

pub fn toolbar_btn<'a>(
    icon_widget: impl Into<Element<'a, Message>>,
    label: &'a str,
    msg: Message,
) -> Button<'a, Message>
A toolbar button with an icon and label text. Used in the header toolbar for Refresh, Open, Close, etc.