Module state

Module state 

Structs

GitKraft
Top-level application state for the GitKraft GUI.
RepoTab
Per-repository state — one instance per open tab.

Enums

ContextMenu
What item was right-clicked to open the context menu.
DragTarget
Which vertical divider the user is currently dragging (if any).
DragTargetH
Which horizontal divider the user is currently dragging (if any).